@@ -1,6 +1,7 @@
 gapsts <- function(ts,            	# array of times, consisting of different continuous subseries seperated by large gaps
                     dtMax,        	# maximum time interval in a continuous series, or equivalently minimum interval to be characterized as gap.
-                    unit = "mins"  	# unit of dtMax; used when ts belongs to class POSIXt
+                    unit = "mins",  	# unit of dtMax; used when ts belongs to class POSIXt
+		    shiftbegin = FALSE	# add time step between fore-last and last measurement before gap to start time (t0) of gap	
                     )
 {
 
@@ -23,6 +24,17 @@ gaps$dt <- gaps$t2 - gaps$t1
 gaps$dt <- difftime(gaps$t2,gaps$t1,units=unit)
 }
 
+if (shiftbegin){
+  if (length(ts) < 3) return("Time series consists of less than 3 data points")
+
+  t1_i <- match(gaps$t1, ts)
+  if (t1_i[1] == 1){
+    t1_i[1] <- 3 # if first data point is beginning of gap, dt cannot be estimated from the former continuous series, but is estimated from the next continuous series
+    warning("First data point is beginning of gap. To shift t0, dt is estimated from next continuous series")
+  }
+  gaps$t1 <- gaps$t1 + Mod(timediffs[t1_i-1])
+}
+
 return(gaps) #Data frame with the initial time, end time and time difference (unit = unit) of each interval > dtMax
 }
 
